==> wf-pytorch-yolo-v4-0.1.7.tar.gz: wf-pytorch-yolo-v4-0.1.7/setup.py <==
import os
from setuptools import setup, find_packages

BASEDIR = os.path.dirname(os.path.abspath(__file__))
VERSION = open(os.path.join(BASEDIR, 'VERSION')).read().strip()

BASE_DEPENDENCIES = [
    'numpy==1.17.5',
    'torch>=1.4.0',
    'tensorboardX>=2.0',
    'scikit_image>=0.16.2',
    'matplotlib>=2.2.3',
    'tqdm>=4.43.0',
    'easydict>=1.9',
    'Pillow>=7.1.2',
    'opencv_python',
    'wf-pycocotools>=2.0.1.2',
    'googledrivedownloader>=0.4'
]

# TEST_DEPENDENCIES = [
# ]
#
# DEVELOPMENT_DEPENDENCIES = [
# ]

# Allow setup.py to be run from any path
os.chdir(os.path.normpath(BASEDIR))


def long_description():
    this_directory = os.path.abspath(os.path.dirname(__file__))
    with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
        return f.read()


setup(
    name='wf-pytorch-yolo-v4',
    packages=find_packages(exclude=('tool.*', 'tool')),
    package_data={'yolov4': ['../cfg/*.cfg', '../data/*.names']},
    version=VERSION,
    include_package_data=True,
    description='Forked version of a minimal PyTorch implementation of YOLOv4',
    long_description=long_description(),
    long_description_content_type='text/markdown',
    original_url='https://github.com/Tianxiaomo/pytorch-YOLOv4',
    original_author='Tianxiaomo',
    url='https://github.com/WildflowerSchools/pytorch-YOLOv4',
    author='Tianxiaomo; Benjamin Jaffe-Talberg',
    author_email='ben.talberg@wildflowerschools.org',
    install_requires=BASE_DEPENDENCIES,
    # tests_require=TEST_DEPENDENCIES,
    # extras_require={
    #     'development': DEVELOPMENT_DEPENDENCIES
    # },
    entry_points={
        "console_scripts": [
            "yolov4 = yolov4:main"
        ]
    },
    keywords=['yolo', 'yolov4', 'pytorch'],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    python_requires=">=3"
)

==> wf-pytorch-yolo-v4-0.1.11.tar.gz: wf-pytorch-yolo-v4-0.1.11/setup.py <==
import os
from setuptools import setup, find_packages

BASEDIR = os.path.dirname(os.path.abspath(__file__))
VERSION = open(os.path.join(BASEDIR, 'VERSION')).read().strip()

BASE_DEPENDENCIES = [
    'numpy>=1.19',
    'torch>=1.4.0',
    'tensorboardX>=2.0',
    'scikit_image>=0.16.2',
    'matplotlib>=2.2.3',
    'tqdm>=4.43.0',
    'easydict>=1.9',
    'Pillow>=7.1.2',
    'opencv_python',
    'wf-pycocotools==2.0.1.1',
    'googledrivedownloader>=0.4'
]

# TEST_DEPENDENCIES = [
# ]
#
# DEVELOPMENT_DEPENDENCIES = [
# ]

# Allow setup.py to be run from any path
os.chdir(os.path.normpath(BASEDIR))


def long_description():
    this_directory = os.path.abspath(os.path.dirname(__file__))
    with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
        return f.read()


setup(
    name='wf-pytorch-yolo-v4',
    packages=find_packages(exclude=('tool.*', 'tool')),
    version=VERSION,
    include_package_data=True,
    description='Forked version of a minimal PyTorch implementation of YOLOv4',
    long_description=long_description(),
    long_description_content_type='text/markdown',
    original_url='https://github.com/Tianxiaomo/pytorch-YOLOv4',
    original_author='Tianxiaomo',
    url='https://github.com/WildflowerSchools/pytorch-YOLOv4',
    author='Tianxiaomo; Benjamin Jaffe-Talberg',
    author_email='ben.talberg@wildflowerschools.org',
    install_requires=BASE_DEPENDENCIES,
    # tests_require=TEST_DEPENDENCIES,
    # extras_require={
    #     'development': DEVELOPMENT_DEPENDENCIES
    # },
    entry_points={
        "console_scripts": [
            "yolov4 = yolov4:main"
        ]
    },
    keywords=['yolo', 'yolov4', 'pytorch'],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
    ],
    python_requires=">=3"
)
